@@ -27,6 +27,8 @@ from natural_selection.genetic_algorithms.operators.mutation import mutation_ran
 from natural_selection.genetic_algorithms.utils.probability_functions import crossover_prob_function_classic, mutation_prob_function_classic
 from natural_selection.genetic_algorithms.utils import clone_classic, GeneticAlgorithmError
 
+from natural_selection import  __version__ as package_version
+
 class Gene:
     """
     A simple class to encapsulate a simple gene.
@@ -307,7 +309,7 @@ class Individual:
             numeric: Fitness value.
         """
         try:
-            self.fitness = self.fitness_function(chromosome=self.chromosome, island=island, **params)
+            self.fitness = self.fitness_function(individual=self, island=island, **params)
         except Exception as exc:
             island._verbose_logging(f"ERROR: {self.name} - {repr(self.chromosome)} - {repr(exc)}")
             raise GeneticAlgorithmError(message=f'Could not evaluate individual "{self.name}" due to {repr(exc)}')
@@ -424,7 +426,7 @@ class Island:
         name (str): General name for island, useful when working with multiple islands (default = None).
         verbose (bool): Print all information (default = None).
         logging_function (Callable): Function for custom message logging, such as server logging (default = None).
-        filepath (str): If a filepath is specified, the pickled island is loaded from it (default = None).
+        filepath (str): If a filepath is specified, the pickled island is loaded from it, skipping the rest of initialisation (default = None).
         save_checkpoint_level (int): Level of checkpoint saving 0 = none, 1 = per generation, 2 = per evaluation (default = 0).
         force_genetic_diversity (bool): Only add new offspring to the population if they have a unique chromosome (default = True).
 
@@ -470,7 +472,7 @@ class Island:
                                 filename=datetime.utcnow().strftime('%Y-%m-%d-ga-output.log'),
                                 datefmt='%H:%M:%S')
 
-        self._verbose_logging(f"island: create")
+        self._verbose_logging(f"island: create v{package_version}")
         if function_params:
             self._verbose_logging(f"island: param {function_params}")
             self.function_params = function_params
@@ -778,11 +780,23 @@ class Island:
         return best_ind
 
     def save_island(self, filepath : str):
+        """
+        Dumps a pickled self to the given file path.
+
+        Args:
+            filepath (str): File path to pickled island.
+        """
         with open(filepath, "wb") as f:
             pickle.dump(self.__dict__, f)
         self._verbose_logging(f"save: file {filepath}")
 
     def load_island(self, filepath : str):
+        """
+        Loads a pickled self from the given file path.
+
+        Args:
+            filepath (str): File path to pickled island.
+        """
         with open(filepath, "rb") as f:
             self.__dict__.update(pickle.load(f))
         self._verbose_logging(f"load: file {filepath}")
@@ -825,7 +839,7 @@ class Island:
                     child.reset_name()
                     child.register_parent_names(parents)
                     child.age = 0
-                    child.reset_fitness()
+                    # child.reset_fitness()
 
                 generation_children.extend(children)
 
@@ -839,7 +853,7 @@ class Island:
 
                 mutated = self.mutation(island=self, individual=mutant, **mutation_params)
 
-                mutated.reset_fitness()
+                # mutated.reset_fitness()
                 generation_mutants.append(mutated)
 
         self.mutants.append({'generation': g, 'mutants': generation_mutants})
