@@ -1,11 +1,11 @@
-def initialise_population_random(adam, n : int, island=None):
+def initialise_population_random(adam, n : int = 10, island=None):
     """
     Classic random initialisation function to create a pool of `n` individuals from a starting Individual `adam`.
 
     Args:
         adam (Individual): An individual already initialised with a chromosome.
-        n (int): Population size.
-        island (Island): Needed to wrap to `create_chromosome` and `create_individual` methods.
+        n (int): Population size (default = 10).
+        island (Island): Needed to wrap to `create_chromosome` and `create_individual` methods (default = None).
 
     Returns:
         list: Population members.
