@@ -17,8 +17,8 @@ def mutation_randomize(individual, prob : float = 0.2, island=None):
     A Classic mutation function, changes a gene of the given individual based on the `prob` strength of mutation.
 
     Args:
-        individual: Individual object containing a Genome.
-        prob: The probability of randomizing genes (default = 0.2).
+        individual (Individual): Individual object containing a Genome.
+        prob (float): The probability of randomizing genes (default = 0.2).
         island (Island): The Island calling the method (default = None).
 
     Returns:
@@ -26,6 +26,8 @@ def mutation_randomize(individual, prob : float = 0.2, island=None):
     """
     for i in range(len(individual.chromosome)):
         if random.random() < prob:
+            island._verbose_logging(f"mutate: gene_before {repr(individual.chromosome[i])}")
             individual.chromosome[i].randomise()
+            island._verbose_logging(f"mutate: gene_after {repr(individual.chromosome[i])}")
 
     return individual
\ No newline at end of file
